@@ -34,6 +34,8 @@ sub new
         $info = eval { WWW::AUR::RPC::info( $name ) };
         Carp::croak( "Failed to find package: $name" ) unless ( $info );
     }
+    $info->{git_clone_ro} = sprintf('https://%s/%s.git', $WWW::AUR::HOST, $name);
+    $info->{git_clone_rw} = sprintf('ssh+git://aur@%s/%s.git', $WWW::AUR::HOST, $name);
 
     my $self = bless { _path_params( @_ ),
                        pkgfile     => "$name.src.tar.gz",
@@ -85,10 +87,11 @@ sub _download_url
 sub download_size
 {
     my ($self) = @_;
-
+    Carp::cluck("Subroutine download_size does not work due to nginx not returning content-length");
+    return 0;
+    # TODO: Fix or remove this
     my $ua   = _useragent();
     my $resp = $ua->head( $self->_download_url() );
-    
     return undef unless $resp->is_success;
     return $resp->header( 'content-length' );
 }
